==> cookieconsent_3.x_5.10.0.zip: lib/ckMonster/Handlers/SobiGoogle.php <==
<?php


namespace ckMonster\Handlers;

use ckMonster\Dom\Finder;
use ckMonster\HandlerInterface;
use Joomla\CMS\Application\CMSApplication;

class SobiGoogle extends BaseHandler implements HandlerInterface
{
    protected $finder;

    public function __construct(\DOMDocument $document, CMSApplication $app)
    {
        parent::__construct($document, $app);

        $this->finder = new Finder($this->dom);
    }

    public function getElements(): \DOMNodeList
    {
        return $this->finder->queryAll([".ctrl-geomap", ".ctrl-geomap-search"]);
    }

    public static function hasElements(string $content): bool
    {
        return strpos($content, 'ctrl-geomap', strpos($content, '</head>')) !== false;
    }

    protected function handleElement(\DOMElement $element)
    {
        $input = $this->finder->query('input', $element);

        if ($input) {
            $input->setAttribute('disabled', true);
            $input->setAttribute('data-placeholder', $input->getAttribute('placeholder'));
            $input->setAttribute('placeholder', \JText::_( 'PLG_COOKIECONSENT_BLOCKED' ));
        }

        $classList = array_map(function($className) {
            return (in_array($className, ['ctrl-geomap', 'ctrl-geomap-search'])) ? "$className-ckmnstr" : $className;
        }, explode(' ', $element->getAttribute('class')));

        $element->setAttribute('class', implode(' ', $classList));
    }

    public function run($content = null)
    {
        parent::run($content);

        // Handle Maps script
        $maps = $this->finder->query("[contains(normalize-space(@src), 'maps.google.com')]");

        $maps->setAttribute('data-consent', 'google-maps');
        $maps->setAttribute('type', 'text/plain');
        $maps->setAttribute('data-type', 'text/javascript');
        $maps->setAttribute('data-src', $maps->getAttribute('src') . '&callback=mapsConsent');
        $maps->removeAttribute('src');


        // Add Callbacks for JS to hook in
        $head = $this->finder->query('head');

        $scriptNode = $this->dom->createElement('script');
        $scriptNode->nodeValue = '
          function mapsConsent() {
            SobiPro.jQuery(\'.ctrl-geomap-search-ckmnstr\').each(function(i,e) {
              const mapCanvas = e.querySelector(\'.ctrl-geomap-ckmnstr\');
              mapCanvas.classList.replace(\'ctrl-geomap-ckmnstr\', \'ctrl-geomap\');

              const input = e.querySelector(\'input\');
              input.removeAttribute(\'disabled\');
              input.setAttribute(\'placeholder\', input.getAttribute(\'data-placeholder\'));

              SobiPro.jQuery(e).SobiProGeoMapGoogleSearch()
            });
            
            SobiPro.jQuery(\'.ctrl-geomap-ckmnstr\').each(function(i,e) {
              SobiPro.jQuery(e).SobiProGeoMapEdit()
            });
          }';

        $head->appendChild($scriptNode);
    }
}

==> cookieconsent_3.x_5.12.1.zip: lib/ckMonster/Handlers/SobiGoogle.php <==
<?php


namespace ckMonster\Handlers;

use ckMonster\Dom\Finder;
use ckMonster\HandlerInterface;
use Joomla\CMS\Application\CMSApplication;

class SobiGoogle extends BaseHandler implements HandlerInterface
{
    protected $finder;

    public function __construct(\DOMDocument $document, CMSApplication $app)
    {
        parent::__construct($document, $app);

        $this->finder = new Finder($this->dom);
    }

    public function getElements(): \DOMNodeList
    {
        return $this->finder->queryAll([".ctrl-geomap", ".ctrl-geomap-search"]);
    }

    public static function hasElements(string $content): bool
    {
        return strpos($content, 'ctrl-geomap', strpos($content, '</head>')) !== false;
    }

    protected function handleElement(\DOMElement $element)
    {
        $input = $this->finder->query('input', $element);

        if ($input) {
            $input->setAttribute('disabled', true);
            $input->setAttribute('data-placeholder', $input->getAttribute('placeholder'));
            $input->setAttribute('placeholder', \JText::_( 'PLG_COOKIECONSENT_BLOCKED' ));
        }

        $classList = array_map(function($className) {
            return (in_array($className, ['ctrl-geomap', 'ctrl-geomap-search'])) ? "$className-ckmnstr" : $className;
        }, explode(' ', $element->getAttribute('class')));

        $element->setAttribute('class', implode(' ', $classList));
    }

    public function run($content = null)
    {
        parent::run($content);

        // Handle Maps script
        $maps = $this->finder->query("[contains(normalize-space(@src), 'maps.google.com')]");

        $maps->setAttribute('data-consent', 'google-maps');
        $maps->setAttribute('type', 'text/plain');
        $maps->setAttribute('data-type', 'text/javascript');
        $maps->setAttribute('data-src', $maps->getAttribute('src') . '&callback=mapsConsent');
        $maps->removeAttribute('src');


        // Add Callbacks for JS to hook in
        $head = $this->finder->query('head');

        $scriptNode = $this->dom->createElement('script');
        $scriptNode->nodeValue = '
          function mapsConsent() {
            SobiPro.jQuery(\'.ctrl-geomap-search-ckmnstr\').each(function(i,e) {
              const mapCanvas = e.querySelector(\'.ctrl-geomap-ckmnstr\');
              mapCanvas.classList.replace(\'ctrl-geomap-ckmnstr\', \'ctrl-geomap\');

              const input = e.querySelector(\'input\');
              input.removeAttribute(\'disabled\');
              input.setAttribute(\'placeholder\', input.getAttribute(\'data-placeholder\'));

              SobiPro.jQuery(e).SobiProGeoMapGoogleSearch()
            });
            
            SobiPro.jQuery(\'.ctrl-geomap-ckmnstr\').each(function(i,e) {
              if (SobiPro.jQuery.fn.SobiProGeoMapEdit) {
                SobiPro.jQuery(e).SobiProGeoMapEdit();
              } else if (SobiPro.jQuery.fn.SobiProGeoMapField) {
                SobiPro.jQuery(e).SobiProGeoMapField();
              }
            });
          }';

        $head->appendChild($scriptNode);
    }
}
